==> cueplot-0.0.2-src.tar.gz: cueplot-0.0.2-src/opt/terminal/TerminalLatexEmtex.cpp <==
/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#include "TerminalLatexEmtex.h"

TerminalLatexEmtex::TerminalLatexEmtex() : isLatex_(true), fontName_(0),
	fontSize_(DEFAULT_FONT_SIZE)
{
	terminalType_ = "latex";
}

void TerminalLatexEmtex::setLatex(bool latex)
{
	isLatex_ = latex;
	terminalType_ = isLatex_ ? "latex" : "emtex";
}

bool TerminalLatexEmtex::isLatex() const
{
	return isLatex_;
}

void TerminalLatexEmtex::setFontName(int name)
{
	fontName_ = name;
}

int TerminalLatexEmtex::fontName() const
{
	return fontName_;
}

void TerminalLatexEmtex::setFontSize(int size)
{
	fontSize_ = size;
}

int TerminalLatexEmtex::fontSize() const
{
	return fontSize_;
}

QString TerminalLatexEmtex::terminalOption() const
{
	if (fontName_) {
		const QString NAME[] = { "roman", "courier" };
		return NAME[fontName_ - 1] + " " 
			+ QString::number(fontSize_);
	}
	return "";
}

==> cueplot-0.0.3-src.tar.gz: cueplot-0.0.3-src/opt/terminal/TerminalLatexEmtex.cpp <==
/*
 * Cueplot: a GUI front-end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#include "TerminalLatexEmtex.h"

const char * const TerminalLatexEmtex::FONT_NAME[] = {
	"courier", "roman", 
	QT_TRANSLATE_NOOP("TerminalLatexEmtex", "default"),
	""
};

const int TerminalLatexEmtex::DEFAULT_FONT_SIZE = 10;

TerminalLatexEmtex::TerminalLatexEmtex() : isLatex_(true), fontName_(2),
	fontSize_(DEFAULT_FONT_SIZE)
{
	terminalType_ = "latex";
}

void TerminalLatexEmtex::setLatex(bool latex)
{
	isLatex_ = latex;
	terminalType_ = isLatex_ ? "latex" : "emtex";
}

bool TerminalLatexEmtex::isLatex() const
{
	return isLatex_;
}

void TerminalLatexEmtex::setFontName(int name)
{
	fontName_ = name;
}

int TerminalLatexEmtex::fontName() const
{
	return fontName_;
}

void TerminalLatexEmtex::setFontSize(int size)
{
	fontSize_ = size;
}

int TerminalLatexEmtex::fontSize() const
{
	return fontSize_;
}

QString TerminalLatexEmtex::terminalOption() const
{
	if (fontName_ != 2) {
		return QString(FONT_NAME[fontName_]) + " " 
			+ QString::number(fontSize_);
	}
	return "";
}
